# Prerequisites
*Feel free to just say what you want and remove this template.*

* [ ] Is it a bug?
* [ ] Is it a new feature?
* [ ] Is it a question?
* [ ] Can you reproduce the problem?
* [ ] Are you running the latest version?
* [ ] Did you check for similar issues?
* [ ] Did you perform a cursory search?

For more information, see the [CONTRIBUTING](https://github.com/nrbnlulu/strawberry-django-auth/blob/main/CONTRIBUTING.md) guide.

# Description

Description of the bug/feature/question

# Steps to Reproduce

If we need to reproduce and you don't provide steps for it, it will be closed. Alternatively, you can link a repo with the code to run your issue.

1. [First Step]
2. [Second Step]
3. [and so on...]

## Expected behavior

What you expected to happen

## Actual behavior

What actually happened

# Requirements

Paste the packages you are using, you can get this information from executing `pip freeze`.
